/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/autkbd.h"              */
/*  Constants and definitions for keyboard automaton.                        */
/*                                                                           */
/*  Author : FA                         Last modification : 21/10/2017       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef AUTKBD_H                       /* If this file is not already        */
#define AUTKBD_H                       /* included, include it.              */


/*
    1    Defines
    ____________
*/


/* Contextes clavier ........................................................*/

#define M5_KBD_CTX            2        /* Num 1er ctx clavier MHEG5          */
#define HBBTV_KBD_CTX     0x100        /* Num ctx clavier HbbTV              */


/* Description d'une touche .................................................*/

#define KPAR_OFF_NBEH         2        /* Comportement de touche.            */
#define KPAR_OFF_NBDF         3        /* Nombre defilements.                */
#define KPAR_OFF_DEFL         4        /* Offset debut defilement.           */


/* Comportements d'une touche ...............................................*/

#define KBEH_NB_EVTS          7        /* Nombre d'evenements.               */
#define KBEH_OFF_LIMT        35        /* Limite d'evenement.                */

#define KEY_MASK_SHORT     (UCHAR)0x01 /* Generer KEY_SHORT                  */
#define KEY_MASK_LONG      (UCHAR)0x02 /* Generer KEY_LONG                   */
#define KEY_MASK_XLONG     (UCHAR)0x04 /* Generer KEY_XLONG                  */
#define KEY_MASK_VALID     (UCHAR)0x08 /* Generer KEY_VALID                  */
#define KEY_MASK_RELEASE   (UCHAR)0x10 /* Generer KEY_RELEASE                */
#define KEY_MASK_REINIT    (UCHAR)0x20 /* Reinitialiser                      */
#define KEY_MASK_DEFIL     (UCHAR)0x40 /* Faire defiler                      */
#define KEY_MASK_BEHAVIOUR (UCHAR)0x80 /* Changer de behaviour               */

#define KPAR_SIZE sizeof(Key_param)    /* Taille de la structure.            */
#define KBEH_SIZE sizeof(Key_behave)   /* Taille de la structure.            */


/*
    2    Structures and typedefs
    ____________________________
*/


typedef struct                         /* Contexte d'une voie logique:       */
  BEGIN                                /* ---------------------------------- */
    INT             res              ; /* Champ reserve                      */
    INT             longueur         ; /* Champ longueur                     */
    UCHAR          *param            ; /* Parametre                          */
    UCHAR           count            ; /* Compteur temporel                  */
    UCHAR           defil            ; /* Defilement courant                 */
    UCHAR           scan             ; /* Scan code                          */
    UCHAR           beh              ; /* Comportement                       */
  END Kbd_ctx                        ; /* ---------------------------------- */

typedef struct                         /* Description d'une touche:          */
  BEGIN                                /* ---------------------------------- */
    USHORT          res              ; /* Champ reserve                      */
    UCHAR           behave           ; /* Offset comportement                */
    UCHAR           nb_defil         ; /* Taille defilement                  */
    USHORT          defil            ; /* Offset defilement                  */
  END Key_param                      ; /* ---------------------------------- */

typedef struct                         /* Comportement d'une touche:         */
  BEGIN                                /* ---------------------------------- */
    UCHAR           evts[5][7]       ; /* MASKs des evts.                    */
    UCHAR           limt   [7]       ; /* Limites temporelles.               */
  END Key_behave                     ; /* ---------------------------------- */

typedef USHORT      Key_defil        ; /* Defilement                         */


/*
    3    Public variables
    _____________________
*/


/*
    4    Prototypes of public procedures
    _____________________________________
*/


  IWORD init_autkbd         (void                                            );
  IWORD autkbd_getvl        (IWORD,IWORD,IWORD,IWORD*                        );
  IWORD autkbd_reset        (void                                            );
  IWORD autkbd_set          (IWORD,IWORD                                     );
  IWORD autkbd_modify       (UCHAR*,IWORD                                    );


#endif                                 /* End of AUTKBD_H.                   */
