/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/defs_stm32.h"          */
/*  Defines for the "const_stm32_inc.c" file.                                */
/*                                                                           */
/*  Author : JYA                        Last modification : 11/23/2018       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Purpose of this module
         2  User manual
            2.1  Contents of this include file
            2.2  How to use this include file
            2.3  List od packages
            2.3  The MCU define selector
                 2.3.1  STM32L100x, STM32L15xx, STM32l162xx
                 2.3.2  STM32F405xx, STM32F407xx
         3  Public defines of this include file
            3.1  Built from the MCU define selector
            3.2  Devices bitmaps
            3.3  RCC input numbers
            3.4  Interrupt controller input numbers
            3.5  Base addresses of the peripherals registers
            3.6  Function mask per pin

*/

#ifndef DEFS_STM32_H                   /* If this file has not already been  */
#define DEFS_STM32_H                   /* included, include its contents     */

/*
    1    Purpose of this module
    ___________________________


         This include file contains of the defines that are needed by the
"const_stm32.inc.c". The reason why those defines have not been directly put
within the "const_st32_inc.c" file is because some them are also to be
included in the "board_xyz.c" files.


         Regarding STM32L151xx and STM32L152xx, two ST Microelectronics
documents have been used :

         - "RM0038 Reference manual", DocID15965 Rev 13, July 2015

         - "STM32L151xE STM32L152xE, DocID025433 Rev 9, AUgust 2017


         Regarding the STM32F405xx and STM32F407xx, two other ST 
Microelectronics documents have been used:

         - "RM0090 Reference manual" (file "STM324xx.pdf"), revision 15 
           (july 2017)

         - "STM32F405xx STM32F407xx" (file "stm32l40x_hw.pdf"), revision 8 
           (september 2016)



    2    User manual
    ________________


    2.1  Contents of this include file

         This file contains STM32 system constant variables and arrays that
are needed by all the STM32 low-level drivers :

         - The number of devices of a same kind
         - Clock control numbers
         - Interrupts requests numbers
         - For each device, the base address for its register block.
         - GPIO description data


         Those const variables are used by the C source codes of the low-level
drivers, as a result the source of each driver do not need to be compiled gain
when the "constant" value is modified, thus reducing the number object files
that have to be specific to one dedicated platform. 


         In order to easily suppress unused const variables, the present file 
contents is a suite of 'pachages" each package corresponding to one low-level 
driver.  For example, when the "stm32_asy" driver is used, the "PKG_asy_stm32" 
macro has to be defined in order that the corresponding const variables are 
compiled.



    2.2  How to use this include file

         A C file that includes this template will contain at least the
following items :

         - "defines" for the packages to be used. The list of the packages
           is provided in "2.3 List of packages". We have one package for each
           low level driver.

         - One and only one define correspondind to the MCU. The possible
           values of the defines are given in "2.4 The MCU define selector"

         - Includes of <stdtyp.l>, <stm32.h> and <stm32_const.h>

         - Include of "./const_stm32_inc"



    2.3  The MCU define selector

    2.3.1  STM32L100x, STM32L15xx, STM32l162xx

         The names that are given here have been found on pages 40 and 41 of 
ST Microelectronics document RM0038:

        STM32L100xx    Register Manual    Data sheet
        -------------  -----------------  --------------------------------
        STM32L100C6    RM0038 Cat 1
        STM32L100R8    RM0038 Cat 1
        STM32L100RB    RM0038 Cat 1
        STM32L100C6_A  RM0038 Cat 2
        STM32L100R8_A  RM0038 Cat 2
        STM32L100RB_A  RM0038 Cat 2
        STM32L100RC    RM0038 Cat 3


        STM32L15xxx    Register Manual    Data sheet
        -------------  -----------------  --------------------------------
        STM32L15xx6    RM0038 Cat 1
        STM32L15xx8    RM0038 Cat 1
        STM32L15xxB    RM0038 Cat 1
        STM32L15xx6_A  RM0038 Cat 2
        STM32L15xx8_A  RM0038 Cat 2
        STM32L15xxB_A  RM0038 Cat 2
        STM32L15xCC    RM0038 Cat 3
        STM32L15xUC    RM0038 Cat 3
        STM32L15xRC    RM0038 Cat 3
        STM32L15xRCY   RM0038 Cat 3
        STM32L15xRC_A  RM0038 Cat 3
        STM32L15xVC    RM0038 Cat 3
        STM32L15xVC_A  RM0038 Cat 3
        STM32L15xQC    RM0038 Cat 3
        STM32L15xZC    RM0038 Cat 3
        STM32L15xRD    RM0038 Cat 4
        STM32L15xVD    RM0038 Cat 4
        STM32L15xQD    RM0038 Cat 4
        STM32L15xZD    RM0038 Cat 4
        STM32L15xxE    RM0038 Cat 5       DocID025433 Rev 9 AUgust 2017
        STM32L15xVD_X  RM0038 Cat 6


        STM32L162xx    Register Manual    Data sheet
        -------------  -----------------  --------------------------------
        STM32L162RC    RM0038 Cat 3
        STM32L162RC_A  RM0038 Cat 3
        STM32L162VC    RM0038 Cat 3
        STM32L162VC_A  RM0038 Cat 3
        STM32L162QC    RM0038 Cat 3
        STM32L162ZC    RM0038 Cat 3
        STM32L162RD    RM0038 Cat 4
        STM32L162VD    RM0038 Cat 4
        STM32L162QD    RM0038 Cat 4
        STM32L162ZD    RM0038 Cat 4
        STM32L162xE    RM0038 Cat 5
        STM32L162VD_X  RM0038 Cat 6



    2.3.2  STM32F405xx, STM32F407xx

         The names that are given here have been found on page 14 of the
STM32405xx STM32F407xx datasheet (DocID022152 Rev 8 September 2016:

        STM32F405xx    Register Manual    Data sheet
        -------------  -----------------  --------------------------------
        STM32F405RG    PM0090             DocID022152 Rev 8 September 2016
        STM32F405OG    PM0090             DocID022152 Rev 8 September 2016
        STM32F405VG    PM0090             DocID022152 Rev 8 September 2016
        STM32F405ZG    PM0090             DocID022152 Rev 8 September 2016
        STM32F405OE    PM0090             DocID022152 Rev 8 September 2016

        STM32F407xx    Register Manual    Data sheet
        -------------  -----------------  --------------------------------
        STM32F407Vx    PM0090             DocID022152 Rev 8 September 2016
        STM32F407Zx    PM0090             DocID022152 Rev 8 September 2016
        STM32F407Ix    PM0090             DocID022152 Rev 8 September 2016



    3    Public defines of this include file
    ________________________________________
*/


/*  3.1  Built from the MCU define selector
    ---------------------------------------

   See pages 40-41 of RM0038 ................................................*/

#define RM0038_CAT1  ( defined(STM32L100C6)    || \
                       defined(STM32L100R8)    || \
                       defined(STM32L100RB)    || \
                       defined(STM32L15xx6)    || \
                       defined(STM32L15xx8)    || \
                       defined(STM32L15xxB)        )

#define RM0038_CAT2  ( defined(STM32L100C6_A)  || \
                       defined(STM32L100R8_A)  || \
                       defined(STM32L100RB_A)  || \
                       defined(STM32L15xx6_A)  || \
                       defined(STM32L15xx8_A)  || \
                       defined(STM32L15xxB_A)      )

#define RM0038_CAT3  ( defined(STM32L100RC)    || \
                       defined(STM32L15xCC)    || \
                       defined(STM32L15xUC)    || \
                       defined(STM32L15xRC)    || \
                       defined(STM32L15xRCY)   || \
                       defined(STM32L15xRC_A)  || \
                       defined(STM32L15xVC)    || \
                       defined(STM32L15xVC_A)  || \
                       defined(STM32L15xQC)    || \
                       defined(STM32L15xZC)    || \
                       defined(STM32L162RC)    || \
                       defined(STM32L162RC_A)  || \
                       defined(STM32L162VC)    || \
                       defined(STM32L162VC_A)  || \
                       defined(STM32L162QC)    || \
                       defined(STM32L162ZC)        )

#define RM0038_CAT4  ( defined(STM32L15xRD)    || \
                       defined(STM32L15xVD)    || \
                       defined(STM32L15xQD)    || \
                       defined(STM32L15xZD)    || \
                       defined(STM32L162RD)    || \
                       defined(STM32L162VD)    || \
                       defined(STM32L162QD)    || \
                       defined(STM32L162ZD)        )

#define RM0038_CAT5  ( defined(STM32L15xxE)    || \
                       defined(STM32L162xE)        )

#define RM0038_CAT6  ( defined(STM32L15xVD_X)  || \
                       defined(STM32L162VD_X)      )

#define RM0038       ( RM0038_CAT1             || \
                       RM0038_CAT2             || \
                       RM0038_CAT3             || \
                       RM0038_CAT4             || \
                       RM0038_CAT5             || \
                       RM0038_CAT6                 )


/*  See pages 14-15 and 19 of DocID022152 Rev 8 September 2016 ..............*/

#define STM32F405_CAT1   defined(STM32F405RG)

#define STM32F405_CAT2 ( defined(STM32F405OG)    || \
                         defined(STM32F405VG)    || \
                         defined(STM32F405ZG)    || \
                         defined(STM32F405OE)        )

#define STM32F407xx    ( defined(STM32F407Vx)    || \
                         defined(STM32F407Zx)    || \
                         defined(STM32F407Ix)        )

#define STM32F40xxx    ( STM32F405_CAT1          || \
                         STM32F405_CAT2          || \
                         STM32F407xx                 )

#define RM0090           STM32F40xxx

/* Error checking ...........................................................*/

#if RM0038 == 0 && RM0090 == 0
#error RM0038 and RM0090 are false
#endif


/*  3.2  Devices bitmaps
    --------------------
*/

#undef GE

#define D0      (1<<0)
#define D1      (1<<1)
#define D2      (1<<2)
#define D3      (1<<3)
#define D4      (1<<4)
#define D5      (1<<5)
#define D6      (1<<6)
#define D7      (1<<7)
#define D8      (1<<8)
#define D9      (1<<9)
#define D10     (1<<10)
#define D11     (1<<11)
#define D12     (1<<12)
#define D13     (1<<13)
#define D14     (1<<14)
#define D0_7   ((1<<0)|(1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7))
#define D1_2   ((1<<1)|(1<<2))
#define D1_3   ((1<<1)|(1<<2)|(1<<3))
#define D1_5   ((1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5))
#define D1_6   ((1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6))
#define D1_7   ((1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7))
#define D2_4   ((1<<2)|(1<<3)|(1<<4))
#define D2_7   ((1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7))
#define D6_7   ((1<<6)|(1<<7) )
#define D9_11  ((1<<9)|(1<<10)|(1<<11))
#define D1_14  0x7FFE

#define GA      (1<<1)
#define GB      (1<<2)
#define GC      (1<<3)
#define GD      (1<<4)
#define GE      (1<<5)
#define GF      (1<<6)
#define GG      (1<<7)
#define GH      (1<<8)
#define GI      (1<<9)
#define GJ      (1<<10)
#define GK      (1<<11)
#define GA_E   ((1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5))
#define GA_H   ((1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7)|(1<<8))
#define GA_I   ((1<<1)|(1<<2)|(1<<3)|(1<<4)|(1<<5)|(1<<6)|(1<<7)|(1<<8)|(1<<9))

#if RM0038_CAT1 || RM0038_CAT2         /* RM0038 page 42                     */
                                       /* ---------------------------------- */
#define TIM_BTM   (D2_4 | D6_7| D9_11) /* timers              9              */
#define GPIO_BTM  (GA_E | GH         ) /* GPIOs               6              */
#define UART_BTM  (D1_3              ) /* USARTs/UARTs        3              */
#define SPI_BTM   (D1_2              ) /* SPIs                2              */
#define I2C_BTM   (D1_2              ) /* I2Cs                2              */
#define USB_BTM   (D1                ) /* USBs                1              */
#define ETH_BTM   (0                 ) /* ETHs                               */
#define CAN_BTM   (0                 ) /* CANs                               */
#define DMA_BTM   (D1                ) /* DMAs                1              */
#define ADC_BTM   (D1                ) /* ADCs                1              */
#define DAC_BTM   (D1                ) /* DACs                1              */
#define OPAMP_BTM (0                 ) /* OPAMPs                             */
#define AES_BTM   (0                 ) /* AESs                               */
#define FSMC_BTM  (0                 ) /* FSMC                               */
#define EXTI_BTM  (1                 ) /* external ITs                       */

#define HCHAN1_BTM (D1_7             ) /* DMA1 Channels                      */
#define HCHAN2_BTM 0                   /* DMA2 Channels                      */
                                       /* ---------------------------------- */
#endif                                 /* RM0038_CAT1 || RM0038_CAT2         */


#if RM0038_CAT3                        /* RM0038 page 43                     */
                                       /* ---------------------------------- */
#define TIM_BTM   (D2_7 | D9_11      ) /* timers              9              */
#define GPIO_BTM  (GA_E | GH         ) /* GPIOs               6              */
#define UART_BTM  (D1_3              ) /* USARTs/UARTs        3              */
#define SPI_BTM   (D1_3              ) /* SPIs                3              */
#define I2C_BTM   (D1_2              ) /* I2Cs                2              */
#define USB_BTM   (D1                ) /* USBs                1              */
#define ETH_BTM   (0                 ) /* ETHs                               */
#define CAN_BTM   (0                 ) /* CANs                               */
#define DMA_BTM   (D1_2              ) /* DMAs                2              */
#define ADC_BTM   (D1                ) /* ADCs                1              */
#define DAC_BTM   (D1                ) /* DACs                1              */
#define OPAMP_BTM (0                 ) /* OPAMPs                             */
#define AES_BTM   (D1                ) /* AESs                1              */
#define FSMC_BTM  (0                 ) /* FSMC                               */
#define EXTI_BTM  (1                 ) /* external ITs                       */

#define HCHAN1_BTM (D1_7             ) /* DMA1 Channels                      */
#define HCHAN2_BTM (D1_5             ) /* DMA2 Channels                      */
                                       /* ---------------------------------- */
#endif                                 /* RM0038_CAT3                        */


#if RM0038_CAT4                        /* RM0038 page 44                     */
                                       /* ---------------------------------- */
#define TIM_BTM   (D2_7 | D9_11      ) /* timers              9              */
#define GPIO_BTM  (GA_H              ) /* GPIOs               8              */
#define UART_BTM  (D1_5              ) /* USARTs/UARTs        5              */
#define SPI_BTM   (D1_3              ) /* SPIs                3              */
#define I2C_BTM   (D1_2              ) /* I2Cs                2              */
#define USB_BTM   (D1                ) /* USBs                1              */
#define ETH_BTM   (0                 ) /* ETHs                               */
#define CAN_BTM   (0                 ) /* CANs                               */
#define DMA_BTM   (D1_2              ) /* DMAs                2              */
#define ADC_BTM   (D1                ) /* ADCs                1              */
#define DAC_BTM   (D1                ) /* DACs                1              */
#define OPAMP_BTM (D1_3              ) /* OPAMPs              3              */
#define AES_BTM   (D1                ) /* AESs                1              */
#define FSMC_BTM  (D1                ) /* FSMC                1              */
#define EXTI_BTM  (1                 ) /* external ITs                       */

#define HCHAN1_BTM (D1_7             ) /* DMA1 Channels                      */
#define HCHAN2_BTM (D1_5             ) /* DMA2 Channels                      */
                                       /* ---------------------------------- */
#endif                                 /* RM0038_CAT4                        */


#if RM0038_CAT5 || RM0038_CAT6         /* RM0038 page 45                     */
                                       /* ---------------------------------- */
#define TIM_BTM   (D2_7 | D9_11      ) /* timers              9              */
#define GPIO_BTM  (GA_H              ) /* GPIOs               8              */
#define UART_BTM  (D1_5              ) /* USARTs/UARTs        5              */
#define SPI_BTM   (D1_3              ) /* SPIs                3              */
#define I2C_BTM   (D1_2              ) /* I2Cs                2              */
#define USB_BTM   (D1                ) /* USBs                1              */
#define ETH_BTM   (0                 ) /* ETHs                               */
#define CAN_BTM   (0                 ) /* CANs                               */
#define DMA_BTM   (D1_2              ) /* DMAs                2              */
#define ADC_BTM   (D1                ) /* ADCs                1              */
#define DAC_BTM   (D1                ) /* DACs                1              */
#define OPAMP_BTM (D1_2              ) /* OPAMPs              2              */
#define AES_BTM   (D1                ) /* AESs                1              */
#define FSMC_BTM  (0                 ) /* FSMC                               */
#define EXTI_BTM  (1                 ) /* external ITs                       */

#define HCHAN1_BTM (D1_7             ) /* DMA1 Channels                      */
#define HCHAN2_BTM (D1_5             ) /* DMA2 Channels                      */
                                       /* ---------------------------------- */
#endif                                 /* RM0038_CAT5 || RM0038_CAT6         */

#if STM32F405_CAT1                     /* STM32F405/404 page 14 & 19         */
                                       /* ---------------------------------- */
#define TIM_BTM   (D1_14             ) /* timers             14              */
#define GPIO_BTM  (GA_I              ) /* GPIOs               9              */
#define UART_BTM  (D1_6              ) /* USARTs/UARTs        6              */
#define SPI_BTM   (D1_3              ) /* SPIs                3              */
#define I2C_BTM   (D1_3              ) /* I2Cs                3              */
#define USB_BTM   (D1                ) /* USBs                1              */
#define ETH_BTM   (0                 ) /* ETHs                               */
#define CAN_BTM   (D1_2              ) /* CANs                2              */
#define DMA_BTM   (D1_2              ) /* DMAs                2              */
#define ADC_BTM   (D1_3              ) /* ADCs                3              */
#define DAC_BTM   (D1_2              ) /* DACs                2              */
#define OPAMP_BTM (0                 ) /* OPAMPs                             */
#define AES_BTM   (D1                ) /* AESs                1              */
#define FSMC_BTM  (0                 ) /* FSMC                               */
#define EXTI_BTM  (1                 ) /* external ITs                       */

#define HCHAN1_BTM D0_7                /* DMA1 Channels                      */
#define HCHAN2_BTM D0_7                /* DMA2 Channels                      */
                                       /* ---------------------------------- */
#endif                                 /* STM32F405_CAT1                     */

#if STM32F405_CAT2                     /* STMF32405/407 page 14 & 19         */
                                       /* ---------------------------------- */
#define TIM_BTM   (D1_14             ) /* timers             14              */
#define GPIO_BTM  (GA_I              ) /* GPIOs               9              */
#define UART_BTM  (D1_6              ) /* USARTs/UARTs        6              */
#define SPI_BTM   (D1_3              ) /* SPIs                3              */
#define I2C_BTM   (D1_3              ) /* I2Cs                3              */
#define USB_BTM   (D1                ) /* USBs                1              */
#define ETH_BTM   (0                 ) /* ETHs                               */
#define CAN_BTM   (D1_2              ) /* CANs                2              */
#define DMA_BTM   (D1_2              ) /* DMAs                2              */
#define ADC_BTM   (D1_3              ) /* ADCs                3              */
#define DAC_BTM   (D1_2              ) /* DACs                2              */
#define OPAMP_BTM (0                 ) /* OPAMPs                             */
#define AES_BTM   (D1                ) /* AESs                1              */
#define FSMC_BTM  (D1                ) /* FSMC                1              */
#define EXTI_BTM  (1                 ) /* external ITs                       */

#define HCHAN1_BTM D0_7                /* DMA1 Channels                      */
#define HCHAN2_BTM D0_7                /* DMA2 Channels                      */
                                       /* ---------------------------------- */
#endif                                 /* STM32F405_CAT2                     */

#if STM32F407xx                        /* STMF32405/407 page 14 & 19         */
                                       /* ---------------------------------- */
#define TIM_BTM   (D1_14             ) /* timers             14              */
#define GPIO_BTM  (GA_I              ) /* GPIOs               9              */
#define UART_BTM  (D1_6              ) /* USARTs/UARTs        6              */
#define SPI_BTM   (D1_3              ) /* SPIs                3              */
#define I2C_BTM   (D1_3              ) /* I2Cs                3              */
#define USB_BTM   (D1                ) /* USBs                1              */
#define ETH_BTM   (D1                ) /* ETHs                1              */
#define CAN_BTM   (D1_2              ) /* CANs                2              */
#define DMA_BTM   (D1_2              ) /* DMAs                2              */
#define ADC_BTM   (D1_3              ) /* ADCs                3              */
#define DAC_BTM   (D1_2              ) /* DACs                2              */
#define OPAMP_BTM (0                 ) /* OPAMPs                             */
#define AES_BTM   (D1                ) /* AESs                1              */
#define FSMC_BTM  (D1                ) /* FSMC                1              */
#define EXTI_BTM  (1                 ) /* external ITs                       */

#define HCHAN1_BTM D0_7                /* DMA1 Channels                      */
#define HCHAN2_BTM D0_7                /* DMA2 Channels                      */
                                       /* ---------------------------------- */
#endif                                 /* STM32F407xx                        */

                                       /* ---------------------------------- */


/*  3.3  RCC input numbers
    ----------------------

    Each peripheral has a "system" number, that corresponds to outputs of
    the RCC (Reset and Clock Control) device. This number is a bit shift
    in the reset registers and also in the clock enable suite of registers.
    Each register is 32 bits wide. For example UART2_SN = 145 = 4 * 32 +17,
    so we have to use bit 17 of register 4, both for "reset" registers and
    "clock enable" registers.

    For the ST32L152, see ST document RM0038 on pages 147-151 for reset's,
    pages 152-159 for clock enable and pages 159-165 for clock enable in
    low power mode.

    For the STM32F405, see ST document RM0090 on pages 170-179 for reset's,
    pages 180-188 for clock enable and pages 189-199 for clock enable in low
    power mode

*/

#if RM0038                             /* RM0038                             */
                                       /* ---------------------------------- */
                                       /* Bus AHB1 page 147 & 159 -----------*/
#define GPIOA_SN                 0     /* \                                0 */
#define GPIOB_SN                 1     /* |                                1 */
#define GPIOC_SN                 2     /* |                                2 */
#define GPIOD_SN                 3     /* |  GPIO                          3 */
#define GPIOE_SN                 4     /* | (A..H)                         4 */
#define GPIOH_SN                 5     /* |                                5 */
#define GPIOF_SN                 6     /* |                                6 */
#define GPIOG_SN                 7     /* /                                7 */
#define CRC_SN                  12     /* Cyclic redundancy check         12 */
#define FLASH_SN                15     /* Flash                           15 */
#define SRAM_SN                 16     /* SRAM clock                      16 */
#define DMA1_SN                 24     /* DMA1                            24 */
#define DMA2_SN                 25     /* DMA2                            25 */
#define AES_SN                  27     /* AES hardware accelerator        27 */
#define FSMC_SN                 30     /* Flexible Memory Controller      30 */
                                       /* Bus APB2 page 149 & 161 ---------- */
#define SYSCFG_SN               32     /* System configuration             0 */
#define TIM9_SN                 34     /* TIM9                             2 */
#define TIM10_SN                35     /* TIM10                            3 */
#define TIM11_SN                36     /* TIM11                            4 */
#define ADC1_SN                 41     /* Analog-Digital Converter         9 */
#define SDIO_SN                 43     /* SD Card I/O                     11 */
#define SPI1_SN                 44     /* SPI1                            12 */
#define USART1_SN               46     /* USART1                          14 */
                                       /* Bus APB1 page 150 & 163 ---------- */
#define TIM2_SN                 64     /* TIM2                             0 */
#define TIM3_SN                 65     /* TIM3                             1 */
#define TIM4_SN                 66     /* TIM4                             2 */
#define TIM5_SN                 67     /* TIM5                             3 */
#define TIM6_SN                 68     /* TIM6                             4 */
#define TIM7_SN                 69     /* TIM7                             5 */
#define LCD_SN                  73     /* Liquid Crystal Display           9 */
#define WWDG_SN                 75     /* Window watchdog                 11 */
#define SPI2_SN                 78     /* SPI2                            14 */
#define SPI3_SN                 79     /* SPI3                            15 */
#define USART2_SN               81     /* USART2                          17 */
#define USART3_SN               82     /* USART3                          18 */
#define UART4_SN                83     /* UART4                           19 */
#define UART5_SN                84     /* UART5                           20 */
#define I2C1_SN                 85     /* I2C1                            21 */
#define I2C2_SN                 86     /* I2C2                            22 */
#define USB_SN                  87     /* USB                             23 */
#define PWR_SN                  92     /* Power                           28 */
#define DAC_SN                  93     /* DAC                             29 */
#define COMP_SN                 95     /* Analog Comparator               31 */
                                       /* Aliases -------------------------- */
#define SRAM1_SN           SRAM_SN     /* SRAM clock                      16 */
#define UART1_SN         USART1_SN     /* USART1                          14 */
#define UART2_SN         USART2_SN     /* USART2                          17 */
#define UART3_SN         USART3_SN     /* USART3                          18 */
                                       /* Do not exist --------------------- */
#define GPIOI_SN                -1     /* GPIOI                              */
#define GPIOJ_SN                -1     /* GPIOJ                              */
#define GPIOK_SN                -1     /* GPIOK                              */
#define SRAM2_SN                -1     /* SRAM 2 interface clock             */
#define BKPSRAM_SN              -1     /* Backup SRAM interface clock        */
#define SRAM3_SN                -1     /* CCM data RAM clock                 */
#define CCMDATA_SN              -1     /* CCM data RAM clock                 */
#define DMA2D_SN                -1     /* DMA 2D                             */
#define ETHMAC_SN               -1     /* Ethernet MAC                       */
#define ETHMACTX_SN             -1     /* Ethernet Transmission clock        */
#define ETHMACRX_SN             -1     /* Ethernet Reception clock           */
#define ETHMACPTP_SN            -1     /* Ethernet PTP clock                 */
#define OTGHS_SN                -1     /* USB OTG HS module                  */
#define OTGHSULPI_SN            -1     /* USB OTG HSULPI clock               */
#define DCMI_SN                 -1     /* Camera interface                   */
#define CRYP_SN                 -1     /* Cryptographic module               */
#define HASH_SN                 -1     /* Hash module                        */
#define RNG_SN                  -1     /* Random number generator module     */
#define OTGFS_SN                -1     /* USB OTG FS module                  */
#define TIM12_SN                -1     /* TIM12                              */
#define TIM13_SN                -1     /* TIM13                              */
#define TIM14_SN                -1     /* TIM14                              */
#define I2C3_SN                 -1     /* I2C3                               */
#define CAN1_SN                 -1     /* CAN1                               */
#define CAN2_SN                 -1     /* CAN2                               */
#define UART7_SN                -1     /* UART7                              */
#define UART8_SN                -1     /* UART8                              */
#define TIM1_SN                 -1     /* TIM1                               */
#define TIM8_SN                 -1     /* TIM8                               */
#define UART6_SN                -1     /* USART6                             */
#define ADC2_SN                 -1     /* ADC2                               */
#define ADC3_SN                 -1     /* ADC3                               */
#define SPI4_SN                 -1     /* SPI4                               */
#define SPI5_SN                 -1     /* SPI5                               */
#define SPI6_SN                 -1     /* SPI6                               */
#define SAI1_SN                 -1     /* SAI1                               */
#define LDTC_SN                 -1     /* LTDC                               */

#endif                                 /* RM0038                             */


#if RM0090                             /* RM0090                             */
                                       /* ---------------------------------- */
                                       /* Bus AHB1 page 181 & 189 -----------*/
#define GPIOA_SN                 0     /* \                                0 */
#define GPIOB_SN                 1     /* |                                1 */
#define GPIOC_SN                 2     /* |                                2 */
#define GPIOD_SN                 3     /* |  GPIO                          3 */
#define GPIOE_SN                 4     /* | (A..K)                         4 */
#define GPIOF_SN                 5     /* |                                5 */
#define GPIOG_SN                 6     /* |                                6 */
#define GPIOH_SN                 7     /* |                                7 */
#define GPIOI_SN                 8     /* |                                8 */
#define GPIOJ_SN                 9     /* |                                9 */
#define GPIOK_SN                10     /*                                 10 */
#define CRC_SN                  12     /* Cyclic redundancy check         11 */
#define FLASH_SN                15     /* Flash interface clock           15 */
#define SRAM1_SN                16     /* SRAM 1 interface clock          16 */
#define SRAM2_SN                17     /* SRAM 2 interface clock          17 */
#define BKPSRAM_SN              18     /* Backup SRAM interface clock     18 */
#define SRAM3_SN                19     /* SRAM 3 interface clock          19 */
#define CCMDATA_SN              20     /* CCM data RAM clock              20 */
#define DMA1_SN                 21     /* DMA1                            21 */
#define DMA2_SN                 22     /* DMA2                            22 */
#define DMA2D_SN                23     /* DMA 2D                          23 */
#define ETHMAC_SN               25     /* Ethernet MAC                    24 */
#define ETHMACTX_SN             26     /* Ethernet Transmission clock     25 */
#define ETHMACRX_SN             27     /* Ethernet Reception clock        26 */
#define ETHMACPTP_SN            28     /* Ethernet PTP clock              27 */
#define OTGHS_SN                29     /* USB OTG HS module               28 */
#define OTGHSULPI_SN            30     /* USB OTG HSULPI clock            29 */
                                       /* Bus AHB2 page 182 & 192 -----------*/
#define DCMI_SN                 32     /* Camera interface                 0 */
#define CRYP_SN                 36     /* Cryptographic module             4 */
#define HASH_SN                 37     /* Hash module                      5 */
#define RNG_SN                  38     /* Random number generator module   6 */
#define OTGFS_SN                39     /* USB OTG FS module                7 */
                                       /* Bus AHB3 page 183 & 193 -----------*/
#define FSMC_SN                 64     /* Flexible Memory Controller       0 */
                                       /* Bus APB1 page 183 & 193 -----------*/
#define TIM2_SN                128     /* TIM2                             0 */
#define TIM3_SN                129     /* TIM3                             1 */
#define TIM4_SN                130     /* TIM4                             2 */
#define TIM5_SN                131     /* TIM5                             3 */
#define TIM6_SN                132     /* TIM6                             4 */
#define TIM7_SN                133     /* TIM7                             5 */
#define TIM12_SN               134     /* TIM12                            6 */
#define TIM13_SN               135     /* TIM13                            7 */
#define TIM14_SN               136     /* TIM14                            8 */
#define WWDG_SN                139     /* Window watchdog                 11 */
#define SPI2_SN                142     /* SPI2                            14 */
#define SPI3_SN                143     /* SPI3                            15 */
#define USART2_SN              145     /* USART2                          17 */
#define USART3_SN              146     /* USART3                          18 */
#define UART4_SN               147     /* UART4                           19 */
#define UART5_SN               148     /* UART5                           20 */
#define I2C1_SN                149     /* I2C1                            21 */
#define I2C2_SN                150     /* I2C2                            22 */
#define I2C3_SN                151     /* I2C3                            23 */
#define CAN1_SN                153     /* CAN1                            25 */
#define CAN2_SN                154     /* CAN2                            26 */
#define PWR_SN                 156     /* Power                           28 */
#define DAC_SN                 157     /* DAC                             29 */
#define UART7_SN               158     /* UART7                           30 */
#define UART8_SN               159     /* UART8                           31 */
                                       /* Bus APB2 page 187 & 197 -----------*/
#define TIM1_SN                160     /* TIM1                             0 */
#define TIM8_SN                161     /* TIM8                             1 */
#define USART1_SN              164     /* USART1                           4 */
#define USART6_SN              165     /* USART6                           5 */
#define ADC1_SN                168     /* ADC1                             8 */
#define ADC2_SN                169     /* ADC2                             9 */
#define ADC3_SN                170     /* ADC3                            10 */
#define SDIO_SN                171     /* SD Card I/O                     11 */
#define SPI1_SN                172     /* SPI1                            12 */
#define SPI4_SN                173     /* SPI4                            13 */
#define SYSCFG_SN              174     /* System configuration            14 */
#define TIM9_SN                176     /* TIM9                            16 */
#define TIM10_SN               177     /* TIM10                           17 */
#define TIM11_SN               178     /* TIM11                           18 */
#define SPI5_SN                180     /* SPI5                            20 */
#define SPI6_SN                181     /* SPI6                            21 */
#define SAI1_SN                182     /* SAI1                            22 */
#define LDTC_SN                186     /* LTDC                            26 */
                                       /* Aliases -------------------------- */
#define UART2_SN         USART2_SN     /* USART2                          17 */
#define UART3_SN         USART3_SN     /* USART3                          18 */
#define UART1_SN         USART1_SN     /* USART1                           4 */
#define UART6_SN         USART6_SN     /* USART6                           5 */
#endif                                 /* RM0090                             */


/*  3.4  Interrupt controller input numbers
    ---------------------------------------

    Each peripheral has an IRQ number, that corresponds to one input of the
    Interrupt Requests Controller.

    For the ST32L152, see ST document RM0038 on pages 230-232. The number is
    the one from the "Position" column.

    For the STM32F405, see ST document RM0090 on pages 372-375. The number is
    the one from the "Position" column.
*/
#if RM0038_CAT1 || RM0038_CAT2         /* RM0038 page 230-232 Table 49       */
                                       /* ---------------------------------- */
#define WWDG_IRQ                 0     /* Window Watchdog                    */
#define PVD_IRQ                  1     /* PVD through EXTI Line detection    */
#define TAMPER_STAMP_IRQ         2     /* TimeStamp throught EXTI Line       */
#define RTC_WKUP_IRQ             3     /* RTC Wakeup throught EXTI Line      */
#define FLASH_IRQ                4     /* Flash global interrupt             */
#define RCC_IRQ                  5     /* RCC global interrupt               */
#define EXTI0_IRQ                6     /* EXTI line 0 interrupt              */
#define EXTI1_IRQ                7     /* EXTI line 1 interrupt              */
#define EXTI2_IRQ                8     /* EXTI line 2 interrupt              */
#define EXTI3_IRQ                9     /* EXTI line 3 interrupt              */
#define EXTI4_IRQ               10     /* EXTI line 4 interrupt              */
#define DMA1_CH1_IRQ            11     /* DMA1 Channel1 global interrupt     */
#define DMA1_CH2_IRQ            12     /* DMA1 Channel2 global interrupt     */
#define DMA1_CH3_IRQ            13     /* DMA1 Channel3 global interrupt     */
#define DMA1_CH4_IRQ            14     /* DMA1 Channel4 global interrupt     */
#define DMA1_CH5_IRQ            15     /* DMA1 Channel5 global interrupt     */
#define DMA1_CH6_IRQ            16     /* DMA1 Channel6 global interrupt     */
#define DMA1_CH7_IRQ            17     /* DMA1 Channel7 global interrupt     */
#define ADC1_IRQ                18     /* ADC1 global interrupt              */
#define USB_HP_IRQ              19     /* USB High priority interrupt        */
#define USB_LP_IRQ              20     /* USB Low priority interrupt         */
#define DAC_IRQ                 21     /* USB Low priority interrupt         */
#define COMP_IRQ                22     /* Comparator wakeup through EXTI     */
#define EXTI9_5_IRQ             23     /* EXTI Line[9:5] interrupts          */
#define LCD_IRQ                 24     /* LCD global interrupt               */
#define TIM9_IRQ                25     /* TIM9 global interrupt              */
#define TIM10_IRQ               26     /* TIM10 global interrupt             */
#define TIM11_IRQ               27     /* TIM11 global interrupt             */
#define TIM2_IRQ                28     /* TIM2 global interrupt              */
#define TIM3_IRQ                29     /* TIM3 global interrupt              */
#define TIM4_IRQ                30     /* TIM4 global interrupt              */
#define I2C1_EV_IRQ             31     /* I2C1 event interrupt               */
#define I2C1_ER_IRQ             32     /* I2C1 error interrupt               */
#define I2C2_EV_IRQ             33     /* I2C2 event interrupt               */
#define I2C2_ER_IRQ             34     /* I2C2 error interrupt               */
#define SPI1_IRQ                35     /* SPI1 global interrupt              */
#define SPI2_IRQ                36     /* SPI2 global interrupt              */
#define USART1_IRQ              37     /* USART1 global interrupt            */
#define USART2_IRQ              38     /* USART2 global interrupt            */
#define USART3_IRQ              39     /* USART3 global interrupt            */
#define EXTI15_10_IRQ           40     /* EXTI Line[15:10] interrupts        */
#define RTC_ALARM_IRQ           41     /* RTC Alarms through EXTI            */
#define USB_FS_WKUP_IRQ         42     /* USB device FS Wakeup through EXTI  */
#define TIM6_IRQ                43     /* TIM6 global interrupt              */
#define TIM7_IRQ                44     /* TIM7 global interrupt              */
                                       /* Aliases -------------------------- */
#define UART1_IRQ       USART1_IRQ     /* USART1 global interrupt            */
#define UART2_IRQ       USART2_IRQ     /* USART2 global interrupt            */
#define UART3_IRQ       USART3_IRQ     /* USART3 global interrupt            */
                                       /* Do not exist --------------------- */
#define TIM5_IRQ                -1     /* TIM5 global interrupt              */
#define SPI3_IRQ                -1     /* SPI3 global interrupt              */
#define DMA1_CH0_IRQ            -1     /* DMA1 Channel0 global interrupt     */
#define DMA2_CH0_IRQ            -1     /* DMA2 Channel0 global interrupt     */
#define DMA2_CH1_IRQ            -1     /* DMA2 Channel1 global interrupt     */
#define DMA2_CH2_IRQ            -1     /* DMA2 Channel2 global interrupt     */
#define DMA2_CH3_IRQ            -1     /* DMA2 Channel3 global interrupt     */
#define DMA2_CH4_IRQ            -1     /* DMA2 Channel4 global interrupt     */
#define DMA2_CH5_IRQ            -1     /* DMA2 Channel5 global interrupt     */
#define AES_IRQ                 -1     /* AES global interrupt               */
#define COMP_ACQ_IRQ            -1     /* Comparator Acquisition glob interr */
#define SDIO_IRQ                -1     /* SDIO global interrupt              */
#define UART4_IRQ               -1     /* UART4 global interrupt             */
#define UART5_IRQ               -1     /* UART5 global interrupt             */
#define CAN1_RX0_IRQ            -1     /* CAN1 RX0 interrupts                */
#define CAN1_RX1_IRQ            -1     /* CAN1 RX1 interrupt                 */
#define CAN1_SCE_IRQ            -1     /* CAN1 SCE interrupt                 */
#define TIM1_IRQ                -1     /* TIM1 global interrupt              */
#define TIM12_IRQ               -1     /* TIM12 global interrupt             */
#define TIM13_IRQ               -1     /* TIM13 global interrupt             */
#define TIM14_IRQ               -1     /* TIM14 global interrupt             */
#define TIM8_IRQ                -1     /* TIM8 Capture compare interrupt     */
#define DMA2_CH5_IRQ            -1     /* DMA2 Stream5 global interrupt      */
#define DMA2_CH6_IRQ            -1     /* DMA2 Stream6 global interrupt      */
#define DMA2_CH7_IRQ            -1     /* DMA2 Stream7 global interrupt      */
#define ETH_IRQ                 -1     /* Ethernet global interrupt          */
#define ETH_WKUP_IRQ            -1     /* Ethernet Wakeup through EXTI line  */
#define CAN2_TX_IRQ             -1     /* CAN2 TX interrupts                 */
#define CAN2_RX0_IRQ            -1     /* CAN2 RX0 interrupts                */
#define CAN2_RX1_IRQ            -1     /* CAN2 RX1 interrupt                 */
#define CAN2_SCE_IRQ            -1     /* CAN2 SCE interrupt                 */
#define UART6_IRQ               -1     /* USART6 global interrupt            */
#define I2C3_EV_IRQ             -1     /* I2C3 event interrupt               */
#define I2C3_ER_IRQ             -1     /* I2C3 error interrupt               */
#define DCMI_IRQ                -1     /* DCMI global interrupt              */
#define CRYPT_IRQ               -1     /* CRYPT crypto global interrupt      */
#define HASH_RNG_IRQ            -1     /* Hash and Rng global interrupt      */
#define FPU_IRQ                 -1     /* FPU global interrupt               */
#endif                                 /* RM0038                             */

#if RM0038_CAT3                        /* RM0038 page 232-235 Table 50       */
                                       /* ---------------------------------- */
#define WWDG_IRQ                 0     /* Window Watchdog                    */
#define PVD_IRQ                  1     /* PVD through EXTI Line detection    */
#define TAMPER_STAMP_IRQ         2     /* TimeStamp throught EXTI Line       */
#define RTC_WKUP_IRQ             3     /* RTC Wakeup throught EXTI Line      */
#define FLASH_IRQ                4     /* Flash global interrupt             */
#define RCC_IRQ                  5     /* RCC global interrupt               */
#define EXTI0_IRQ                6     /* EXTI line 0 interrupt              */
#define EXTI1_IRQ                7     /* EXTI line 1 interrupt              */
#define EXTI2_IRQ                8     /* EXTI line 2 interrupt              */
#define EXTI3_IRQ                9     /* EXTI line 3 interrupt              */
#define EXTI4_IRQ               10     /* EXTI line 4 interrupt              */
#define DMA1_CH1_IRQ            11     /* DMA1 Channel1 global interrupt     */
#define DMA1_CH2_IRQ            12     /* DMA1 Channel2 global interrupt     */
#define DMA1_CH3_IRQ            13     /* DMA1 Channel3 global interrupt     */
#define DMA1_CH4_IRQ            14     /* DMA1 Channel4 global interrupt     */
#define DMA1_CH5_IRQ            15     /* DMA1 Channel5 global interrupt     */
#define DMA1_CH6_IRQ            16     /* DMA1 Channel6 global interrupt     */
#define DMA1_CH7_IRQ            17     /* DMA1 Channel7 global interrupt     */
#define ADC1_IRQ                18     /* ADC1 global interrupt              */
#define USB_HP_IRQ              19     /* USB High priority interrupt        */
#define USB_LP_IRQ              20     /* USB Low priority interrupt         */
#define DAC_IRQ                 21     /* USB Low priority interrupt         */
#define COMP_IRQ                22     /* Comparator wakeup through EXTI     */
#define EXTI9_5_IRQ             23     /* EXTI Line[9:5] interrupts          */
#define LCD_IRQ                 24     /* LCD global interrupt               */
#define TIM9_IRQ                25     /* TIM9 global interrupt              */
#define TIM10_IRQ               26     /* TIM10 global interrupt             */
#define TIM11_IRQ               27     /* TIM11 global interrupt             */
#define TIM2_IRQ                28     /* TIM2 global interrupt              */
#define TIM3_IRQ                29     /* TIM3 global interrupt              */
#define TIM4_IRQ                30     /* TIM4 global interrupt              */
#define I2C1_EV_IRQ             31     /* I2C1 event interrupt               */
#define I2C1_ER_IRQ             32     /* I2C1 error interrupt               */
#define I2C2_EV_IRQ             33     /* I2C2 event interrupt               */
#define I2C2_ER_IRQ             34     /* I2C2 error interrupt               */
#define SPI1_IRQ                35     /* SPI1 global interrupt              */
#define SPI2_IRQ                36     /* SPI2 global interrupt              */
#define USART1_IRQ              37     /* USART1 global interrupt            */
#define USART2_IRQ              38     /* USART2 global interrupt            */
#define USART3_IRQ              39     /* USART3 global interrupt            */
#define EXTI15_10_IRQ           40     /* EXTI Line[15:10] interrupts        */
#define RTC_ALARM_IRQ           41     /* RTC Alarms through EXTI            */
#define USB_FS_WKUP_IRQ         42     /* USB device FS Wakeup through EXTI  */
#define TIM6_IRQ                43     /* TIM6 global interrupt              */
#define TIM7_IRQ                44     /* TIM7 global interrupt              */
#define TIM5_IRQ                45     /* TIM5 global interrupt              */
#define SPI3_IRQ                46     /* SPI3 global interrupt              */
#define DMA2_CH1_IRQ            47     /* DMA2 Channel1 global interrupt     */
#define DMA2_CH2_IRQ            48     /* DMA2 Channel2 global interrupt     */
#define DMA2_CH3_IRQ            49     /* DMA2 Channel3 global interrupt     */
#define DMA2_CH4_IRQ            50     /* DMA2 Channel4 global interrupt     */
#define DMA2_CH5_IRQ            51     /* DMA2 Channel5 global interrupt     */
#define AES_IRQ                 52     /* AES global interrupt               */
#define COMP_ACQ_IRQ            53     /* Comparator Acquisition glob interr */
                                       /* Aliases -------------------------- */
#define UART1_IRQ       USART1_IRQ     /* USART1 global interrupt            */
#define UART2_IRQ       USART2_IRQ     /* USART2 global interrupt            */
#define UART3_IRQ       USART3_IRQ     /* USART3 global interrupt            */
                                       /* Do not exist --------------------- */
#define SDIO_IRQ                -1     /* SDIO global interrupt              */
#define UART4_IRQ               -1     /* UART4 global interrupt             */
#define UART5_IRQ               -1     /* UART5 global interrupt             */
#define CAN1_TX_IRQ             -1     /* CAN1 TX interrupts                 */
#define CAN1_RX0_IRQ            -1     /* CAN1 RX0 interrupts                */
#define CAN1_RX1_IRQ            -1     /* CAN1 RX1 interrupt                 */
#define CAN1_SCE_IRQ            -1     /* CAN1 SCE interrupt                 */
#define TIM1_IRQ                -1     /* TIM1 global interrupt              */
#define TIM12_IRQ               -1     /* TIM12 global interrupt             */
#define TIM13_IRQ               -1     /* TIM13 global interrupt             */
#define TIM14_IRQ               -1     /* TIM14 global interrupt             */
#define TIM8_IRQ                -1     /* TIM8 Capture compare interrupt     */
#define DMA1_CH0_IRQ            -1     /* DMA1 Channel0 global interrupt     */
#define DMA2_CH0_IRQ            -1     /* DMA2 Channel0 global interrupt     */
#define DMA2_CH5_IRQ            -1     /* DMA2 Stream5 global interrupt      */
#define DMA2_CH6_IRQ            -1     /* DMA2 Stream6 global interrupt      */
#define DMA2_CH7_IRQ            -1     /* DMA2 Stream7 global interrupt      */
#define ETH_IRQ                 -1     /* Ethernet global interrupt          */
#define ETH_WKUP_IRQ            -1     /* Ethernet Wakeup through EXTI line  */
#define CAN2_TX_IRQ             -1     /* CAN2 TX interrupts                 */
#define CAN2_RX0_IRQ            -1     /* CAN2 RX0 interrupts                */
#define CAN2_RX1_IRQ            -1     /* CAN2 RX1 interrupt                 */
#define CAN2_SCE_IRQ            -1     /* CAN2 SCE interrupt                 */
#define UART6_IRQ               -1     /* USART6 global interrupt            */
#define I2C3_EV_IRQ             -1     /* I2C3 event interrupt               */
#define I2C3_ER_IRQ             -1     /* I2C3 error interrupt               */
#define DCMI_IRQ                -1     /* DCMI global interrupt              */
#define CRYPT_IRQ               -1     /* CRYPT crypto global interrupt      */
#define HASH_RNG_IRQ            -1     /* Hash and Rng global interrupt      */
#define FPU_IRQ                 -1     /* FPU global interrupt               */
#endif                                 /* RM0038                             */

#if RM0038_CAT4 || RM0038_CAT5 || \
    RM0038_CAT6                        /* RM0038 page 235-237 Table 51       */
                                       /* ---------------------------------- */
#define WWDG_IRQ                 0     /* Window Watchdog                    */
#define PVD_IRQ                  1     /* PVD through EXTI Line detection    */
#define TAMPER_STAMP_IRQ         2     /* TimeStamp throught EXTI Line       */
#define RTC_WKUP_IRQ             3     /* RTC Wakeup throught EXTI Line      */
#define FLASH_IRQ                4     /* Flash global interrupt             */
#define RCC_IRQ                  5     /* RCC global interrupt               */
#define EXTI0_IRQ                6     /* EXTI line 0 interrupt              */
#define EXTI1_IRQ                7     /* EXTI line 1 interrupt              */
#define EXTI2_IRQ                8     /* EXTI line 2 interrupt              */
#define EXTI3_IRQ                9     /* EXTI line 3 interrupt              */
#define EXTI4_IRQ               10     /* EXTI line 4 interrupt              */
#define DMA1_CH1_IRQ            11     /* DMA1 Channel1 global interrupt     */
#define DMA1_CH2_IRQ            12     /* DMA1 Channel2 global interrupt     */
#define DMA1_CH3_IRQ            13     /* DMA1 Channel3 global interrupt     */
#define DMA1_CH4_IRQ            14     /* DMA1 Channel4 global interrupt     */
#define DMA1_CH5_IRQ            15     /* DMA1 Channel5 global interrupt     */
#define DMA1_CH6_IRQ            16     /* DMA1 Channel6 global interrupt     */
#define DMA1_CH7_IRQ            17     /* DMA1 Channel7 global interrupt     */
#define ADC1_IRQ                18     /* ADC1 global interrupt              */
#define USB_HP_IRQ              19     /* USB High priority interrupt        */
#define USB_LP_IRQ              20     /* USB Low priority interrupt         */
#define DAC_IRQ                 21     /* USB Low priority interrupt         */
#define COMP_IRQ                22     /* Comparator wakeup through EXTI     */
#define EXTI9_5_IRQ             23     /* EXTI Line[9:5] interrupts          */
#define LCD_IRQ                 24     /* LCD global interrupt               */
#define TIM9_IRQ                25     /* TIM9 global interrupt              */
#define TIM10_IRQ               26     /* TIM10 global interrupt             */
#define TIM11_IRQ               27     /* TIM11 global interrupt             */
#define TIM2_IRQ                28     /* TIM2 global interrupt              */
#define TIM3_IRQ                29     /* TIM3 global interrupt              */
#define TIM4_IRQ                30     /* TIM4 global interrupt              */
#define I2C1_EV_IRQ             31     /* I2C1 event interrupt               */
#define I2C1_ER_IRQ             32     /* I2C1 error interrupt               */
#define I2C2_EV_IRQ             33     /* I2C2 event interrupt               */
#define I2C2_ER_IRQ             34     /* I2C2 error interrupt               */
#define SPI1_IRQ                35     /* SPI1 global interrupt              */
#define SPI2_IRQ                36     /* SPI2 global interrupt              */
#define USART1_IRQ              37     /* USART1 global interrupt            */
#define USART2_IRQ              38     /* USART2 global interrupt            */
#define USART3_IRQ              39     /* USART3 global interrupt            */
#define EXTI15_10_IRQ           40     /* EXTI Line[15:10] interrupts        */
#define RTC_ALARM_IRQ           41     /* RTC Alarms through EXTI            */
#define USB_FS_WKUP_IRQ         42     /* USB device FS Wakeup through EXTI  */
#define TIM6_IRQ                43     /* TIM6 global interrupt              */
#define TIM7_IRQ                44     /* TIM7 global interrupt              */
#define SDIO_IRQ                45     /* SDIO global interrupt              */
#define TIM5_IRQ                46     /* TIM5 global interrupt              */
#define SPI3_IRQ                47     /* SPI3 global interrupt              */
#define UART4_IRQ               48     /* UART4 global interrupt             */
#define UART5_IRQ               49     /* UART5 global interrupt             */
#define DMA2_CH1_IRQ            50     /* DMA2 Channel1 global interrupt     */
#define DMA2_CH2_IRQ            51     /* DMA2 Channel2 global interrupt     */
#define DMA2_CH3_IRQ            52     /* DMA2 Channel3 global interrupt     */
#define DMA2_CH4_IRQ            53     /* DMA2 Channel4 global interrupt     */
#define DMA2_CH5_IRQ            54     /* DMA2 Channel5 global interrupt     */
#define AES_IRQ                 55     /* AES global interrupt               */
#define COMP_ACQ_IRQ            56     /* Comparator Acquisition glob interr */
                                   /* Aliases -------------------------- */
#define UART1_IRQ       USART1_IRQ     /* USART1 global interrupt            */
#define UART2_IRQ       USART2_IRQ     /* USART2 global interrupt            */
#define UART3_IRQ       USART3_IRQ     /* USART3 global interrupt            */
                                       /* Do not exist --------------------- */
#define CAN1_TX_IRQ             -1     /* CAN1 TX interrupts                 */
#define CAN1_RX0_IRQ            -1     /* CAN1 RX0 interrupts                */
#define CAN1_RX1_IRQ            -1     /* CAN1 RX1 interrupt                 */
#define CAN1_SCE_IRQ            -1     /* CAN1 SCE interrupt                 */
#define TIM1_IRQ                -1     /* TIM1 global interrupt              */
#define TIM12_IRQ               -1     /* TIM12 global interrupt             */
#define TIM13_IRQ               -1     /* TIM13 global interrupt             */
#define TIM14_IRQ               -1     /* TIM14 global interrupt             */
#define TIM8_IRQ                -1     /* TIM8 Capture compare interrupt     */
#define DMA1_CH0_IRQ            -1     /* DMA1 Channel0 global interrupt     */
#define DMA2_CH0_IRQ            -1     /* DMA2 Channel0 global interrupt     */
#define DMA2_CH6_IRQ            -1     /* DMA2 Stream6 global interrupt      */
#define DMA2_CH7_IRQ            -1     /* DMA2 Stream7 global interrupt      */
#define ETH_IRQ                 -1     /* Ethernet global interrupt          */
#define ETH_WKUP_IRQ            -1     /* Ethernet Wakeup through EXTI line  */
#define CAN2_TX_IRQ             -1     /* CAN2 TX interrupts                 */
#define CAN2_RX0_IRQ            -1     /* CAN2 RX0 interrupts                */
#define CAN2_RX1_IRQ            -1     /* CAN2 RX1 interrupt                 */
#define CAN2_SCE_IRQ            -1     /* CAN2 SCE interrupt                 */
#define UART6_IRQ               -1     /* USART6 global interrupt            */
#define I2C3_EV_IRQ             -1     /* I2C3 event interrupt               */
#define I2C3_ER_IRQ             -1     /* I2C3 error interrupt               */
#define DCMI_IRQ                -1     /* DCMI global interrupt              */
#define CRYPT_IRQ               -1     /* CRYPT crypto global interrupt      */
#define HASH_RNG_IRQ            -1     /* Hash and Rng global interrupt      */
#define FPU_IRQ                 -1     /* FPU global interrupt               */
#endif                                 /* RM0038                             */

#if RM0090                             /* RM0090 p 372-375                   */
                                       /* ---------------------------------- */
#define WWDG_IRQ                 0     /* Window Watchdog                    */
#define PVD_IRQ                  1     /* PVD through EXTI Line detection    */
#define TAMPER_STAMP_IRQ         2     /* TimeStamp throught EXTI Line       */
#define RTC_WKUP_IRQ             3     /* RTC Wakeup throught EXTI Line      */
#define FLASH_IRQ                4     /* Flash global interrupt             */
#define RCC_IRQ                  5     /* RCC global interrupt               */
#define EXTI0_IRQ                6     /* EXTI line 0 interrupt              */
#define EXTI1_IRQ                7     /* EXTI line 1 interrupt              */
#define EXTI2_IRQ                8     /* EXTI line 2 interrupt              */
#define EXTI3_IRQ                9     /* EXTI line 3 interrupt              */
#define EXTI4_IRQ               10     /* EXTI line 4 interrupt              */
#define DMA1_STREAM0_IRQ        11     /* DMA1 Stream0 global interrupt      */
                                       /* page 373                           */
#define DMA1_STREAM1_IRQ        12     /* DMA1 Stream1 global interrupt      */
#define DMA1_STREAM2_IRQ        13     /* DMA1 Stream2 global interrupt      */
#define DMA1_STREAM3_IRQ        14     /* DMA1 Stream3 global interrupt      */
#define DMA1_STREAM4_IRQ        15     /* DMA1 Stream4 global interrupt      */
#define DMA1_STREAM5_IRQ        16     /* DMA1 Stream5 global interrupt      */
#define DMA1_STREAM6_IRQ        17     /* DMA1 Stream6 global interrupt      */
#define ADC1_IRQ                18     /* ADC1,ADC2,ADC3 global interrupt    */
#define CAN1_TX_IRQ             19     /* CAN1 TX interrupts                 */
#define CAN1_RX0_IRQ            20     /* CAN1 RX0 interrupts                */
#define CAN1_RX1_IRQ            21     /* CAN1 RX1 interrupt                 */
#define CAN1_SCE_IRQ            22     /* CAN1 SCE interrupt                 */
#define EXTI9_5_IRQ             23     /* EXTI Line[9:5] interrupts          */
#define TIM1_BRK_TIM9_IRQ       24     /* TIM1 break + TIM9 global interr.   */
#define TIM1_BRK_TIM10_IRQ      25     /* TIM1 update + TIM10 global interr. */
#define TIM1_TRG_TIM11_IRQ      26     /* TIM1 trigger + TIM11 global interr */
#define TIM1_CC_IRQ             27     /* TIM1 Capture Compare interrupt     */
#define TIM2_IRQ                28     /* TIM2 global interrupt              */
#define TIM3_IRQ                29     /* TIM3 global interrupt              */
#define TIM4_IRQ                30     /* TIM4 global interrupt              */
#define I2C1_EV_IRQ             31     /* I2C1 event interrupt               */
#define I2C1_ER_IRQ             32     /* I2C1 error interrupt               */
#define I2C2_EV_IRQ             33     /* I2C2 event interrupt               */
#define I2C2_ER_IRQ             34     /* I2C2 error interrupt               */
#define SPI1_IRQ                35     /* SPI1 global interrupt              */
#define SPI2_IRQ                36     /* SPI2 global interrupt              */
#define USART1_IRQ              37     /* USART1 global interrupt            */
#define USART2_IRQ              38     /* USART2 global interrupt            */
#define USART3_IRQ              39     /* USART3 global interrupt            */
                                       /* page 374                           */
#define EXTI15_10_IRQ           40     /* EXTI Line[15:10] interrupts        */
#define RTC_ALARM_IRQ           41     /* RTC Alarms through EXTI            */
#define USB_FS_WKUP_IRQ         42     /* USB device FS Wakeup through EXTI  */
#define TIM8_BRK_TIM12_IRQ      43     /* TIM8 break + TIM12 global interr.  */
#define TIM8_UP_TIM13_IRQ       44     /* TIM8 update + TIM13 global interr  */
#define TIM8_TRG_TIM14_IRQ      45     /* TIM8 trigger + TIM14 global interr */
#define TIM8_CC_IRQ             46     /* TIM8 Capture Compare interrupt     */
#define DMA1_STREAM7_IRQ        47     /* DMA1 Stream7 global interrupt      */
#define FSMC_IRQ                48     /* FSMC global interrupt              */
#define SDIO_IRQ                49     /* SDIO global interrupt              */
#define TIM5_IRQ                50     /* TIM5 global interrupt              */
#define SPI3_IRQ                51     /* SPI3 global interrupt              */
#define UART4_IRQ               52     /* UART4 global interrupt             */
#define UART5_IRQ               53     /* UART5 global interrupt             */
#define TIM6_DAC_IRQ            54     /* TIM6 global + DAC1/2 underrun err  */
#define TIM7_IRQ                55     /* TIM7 global interrupt              */
#define DMA2_STREAM0_IRQ        56     /* DAM2 Stream0 global interrupt      */
#define DMA2_STREAM1_IRQ        57     /* DAM2 Stream1 global interrupt      */
#define DMA2_STREAM2_IRQ        58     /* DAM2 Stream2 global interrupt      */
#define DMA2_STREAM3_IRQ        59     /* DAM2 Stream3 global interrupt      */
#define DMA2_STREAM4_IRQ        60     /* DAM2 Stream4 global interrupt      */
#define ETH_IRQ                 61     /* Ethernet global interrupt          */
#define ETH_WKUP_IRQ            62     /* Ethernet Wakeup through EXTI line  */
#define CAN2_TX_IRQ             63     /* CAN2 TX interrupts                 */
#define CAN2_RX0_IRQ            64     /* CAN2 RX0 interrupts                */
                                       /* page 375                           */
#define CAN2_RX1_IRQ            65     /* CAN2 RX1 interrupt                 */
#define CAN2_SCE_IRQ            66     /* CAN2 SCE interrupt                 */
#define OTG_FS_IRQ              67     /* USB OTG FS global interrupt        */
#define DMA2_STREAM5_IRQ        68     /* DMA2 Stream5 global interrupt      */
#define DMA2_STREAM6_IRQ        69     /* DMA2 Stream6 global interrupt      */
#define DMA2_STREAM7_IRQ        70     /* DMA2 Stream7 global interrupt      */
#define USART6_IRQ              71     /* USART6 global interrupt            */
#define I2C3_EV_IRQ             72     /* I2C3 event interrupt               */
#define I2C3_ER_IRQ             73     /* I2C3 error interrupt               */
#define OTG_HS_EP1_OUT_IRQ      74     /* USB HS EndPoint 1 OUT interrupt    */
#define OTG_HS_EP1_IN_IRQ       75     /* USB HS EndPoint 1 IN  interrupt    */
#define OTG_HS_WKUP_IRQ         76     /* USB HS Wakeup through EXTI interr. */
#define OTG_HS_IRQ              77     /* USB HS global interrupt            */
#define DCMI_IRQ                78     /* DCMI global interrupt              */
#define CRYPT_IRQ               79     /* CRYPT crypto global interrupt      */
#define HASH_RNG_IRQ            80     /* Hash and Rng global interrupt      */
#define FPU_IRQ                 81     /* FPU global interrupt               */
                                       /* Aliases -------------------------- */
#define UART1_IRQ       USART1_IRQ     /* USART1 global interrupt            */
#define UART2_IRQ       USART2_IRQ     /* USART2 global interrupt            */
#define UART3_IRQ       USART3_IRQ     /* USART3 global interrupt            */
#define DMA1_CH0_IRQ            11     /* DMA1 Stream0 global interrupt      */
#define DMA1_CH1_IRQ            12     /* DMA1 Stream1 global interrupt      */
#define DMA1_CH2_IRQ            13     /* DMA1 Stream2 global interrupt      */
#define DMA1_CH3_IRQ            14     /* DMA1 Stream3 global interrupt      */
#define DMA1_CH4_IRQ            15     /* DMA1 Stream4 global interrupt      */
#define DMA1_CH5_IRQ            16     /* DMA1 Stream5 global interrupt      */
#define DMA1_CH6_IRQ            17     /* DMA1 Stream6 global interrupt      */
#define DMA1_CH7_IRQ            47     /* DMA1 Stream7 global interrupt      */
#define TIM9_IRQ                24     /* TIM9 global interrupt              */
#define TIM10_IRQ               25     /* TIM10 global interrupt             */
#define TIM11_IRQ               26     /* TIM11 global interrupt             */
#define TIM1_IRQ                27     /* TIM1  Capture Compare interrupt    */
#define TIM12_IRQ               43     /* TIM12 global interrupt             */
#define TIM13_IRQ               44     /* TIM13 global interrupt             */
#define TIM14_IRQ               45     /* TIM14 global interrupt             */
#define TIM8_IRQ                46     /* TIM8  Capture Compare interrupt    */
#define TIM6_IRQ                54     /* TIM6  global interrupt             */
#define DAC_IRQ                 54     /* DAC1/2 underrun err                */
#define DMA2_CH0_IRQ            56     /* DAM2 Stream0 global interrupt      */
#define DMA2_CH1_IRQ            57     /* DAM2 Stream1 global interrupt      */
#define DMA2_CH2_IRQ            58     /* DAM2 Stream2 global interrupt      */
#define DMA2_CH3_IRQ            59     /* DAM2 Stream3 global interrupt      */
#define DMA2_CH4_IRQ            60     /* DAM2 Stream4 global interrupt      */
#define DMA2_CH5_IRQ            68     /* DMA2 Stream5 global interrupt      */
#define DMA2_CH6_IRQ            69     /* DMA2 Stream6 global interrupt      */
#define DMA2_CH7_IRQ            70     /* DMA2 Stream7 global interrupt      */
#define UART6_IRQ       USART6_IRQ     /* USART6 global interrupt            */

#endif                                 /* RM0090                             */


/*  3.5  Base addresses of the peripherals registers
    ------------------------------------------------
*/

#define SYSTICK_BA      0xE000E010     /* ARMv7-M Architecture Reference     */
                                       /* Manual Part B, page B3-745         */

#if RM0038                             /* RM0038 page 47                     */
                                       /* ---------------------------------- */
#define FSMS_BA         0xA0000000     /* FSMC                               */
#define AES_BA          0x50060000     /* AES                                */
#define DMA2_BA         0x40026400     /* DMA2                               */
#define DMA1_BA         0x40026000     /* DMA1                               */
#define FLASH_BA        0x40023C00     /* FLASH                              */
#define RCC_BA          0x40023800     /* RCC                                */
#define CRC_BA          0x40023000     /* CRC                                */
#define GPIOG_BA        0x40021C00     /* GPIOG                              */
#define GPIOF_BA        0x40021800     /* GPIOF                              */
#define GPIOH_BA        0x40021400     /* GPIOH                              */
#define GPIOE_BA        0x40021000     /* GPIOE                              */
#define GPIOD_BA        0x40020C00     /* GPIOD                              */
#define GPIOC_BA        0x40020800     /* GPIOC                              */
#define GPIOB_BA        0x40020400     /* GPIOB                              */
#define GPIOA_BA        0x40020000     /* GPIOA                              */
#define USART1_BA       0x40013800     /* USART1                             */
#define SPI1_BA         0x40013000     /* SPI1                               */
#define SDIO_BA         0x40012C00     /* SDIO                               */
#define ADC_BA          0x40012400     /* ADC                                */
#define TIM11_BA        0x40011000     /* TIM11                              */
#define TIM10_BA        0x40010C00     /* TIM10                              */
#define TIM9_BA         0x40010800     /* TIM9                               */
#define EXTI_BA         0x40010400     /* EXTI                               */
#define SYSCFG_BA       0x40010000     /* SYSCFG                             */
                                       /* RM0038 page 48 ------------------- */
#define COMP_BA         0x40007C00     /* COMP                               */
#define RI_BA           0x40007C04     /* RI                                 */
#define OPAMP_BA        0x40007C5C     /* OPAMP                              */
#define DAC_BA          0x40007400     /* DAC                                */
#define PWR_BA          0x40007000     /* PWR                                */
#define USB_RAM         0x40006000     /* USB RAM                            */
#define USB_BA          0x40005C00     /* USB device Full Speed              */
#define I2C2_BA         0x40005800     /* I2C2                               */
#define I2C1_BA         0x40005400     /* I2C1                               */
#define USART5_BA       0x40005000     /* USART5                             */
#define USART4_BA       0x40004C00     /* USART4                             */
#define USART3_BA       0x40004800     /* USART3                             */
#define USART2_BA       0x40004400     /* USART2                             */
#define SPI3_BA         0x40003C00     /* SPI3                               */
#define SPI2_BA         0x40003800     /* SPI2                               */
#define IWDG_BA         0x40003000     /* IWDG                               */
#define WWDG_BA         0x40002C00     /* WWDG                               */
#define RTC_BA          0x40002800     /* RTC                                */
#define LCD_BA          0x40002400     /* LCD                                */
#define TIM7_BA         0x40001400     /* TIM7                               */
#define TIM6_BA         0x40001000     /* TIM6                               */
#define TIM5_BA         0x40000C00     /* TIM5 (32 bits)                     */
#define TIM4_BA         0x40000800     /* TIM4                               */
#define TIM3_BA         0x40000400     /* TIM3                               */
#define TIM2_BA         0x40000000     /* TIM2                               */
                                       /* Aliases -------------------------- */
#define UART5_BA         USART5_BA     /* USART5                             */
#define UART4_BA         USART4_BA     /* USART4                             */
#define UART3_BA         USART3_BA     /* USART3                             */
#define UART2_BA         USART2_BA     /* USART2                             */
#define UART1_BA         USART1_BA     /* USART1                             */
                                       /* Do not exist --------------------- */
#define HASH_BA         0xFFFFFFFF     /* HASH                               */
#define CRYPT_BA        0xFFFFFFFF     /* CRYPT                              */
#define DCMI_BA         0xFFFFFFFF     /* DCMI                               */
#define USBFS_BA        0xFFFFFFFF     /* USB OTG Full Speed                 */
#define USBHS_BA        0xFFFFFFFF     /* USB OTG High Speed                 */
#define DMA2D_BA        0xFFFFFFFF     /* DMA2D                              */
#define ETH_BA          0xFFFFFFFF     /* ETH                                */
#define BKPSRAM_BA      0xFFFFFFFF     /* BKPSRAM                            */
#define GPIOK_BA        0xFFFFFFFF     /* GPIOK                              */
#define GPIOJ_BA        0xFFFFFFFF     /* GPIOJ                              */
#define GPIOI_BA        0xFFFFFFFF     /* GPIOI                              */
#define LCD_TFT_BA      0xFFFFFFFF     /* LCD TFT                            */
#define SAI1_BA         0xFFFFFFFF     /* SAI1                               */
#define SPI6_BA         0xFFFFFFFF     /* SPI6                               */
#define SPI5_BA         0xFFFFFFFF     /* SPI5                               */
#define SPI4_BA         0xFFFFFFFF     /* SPI4                               */
#define UART6_BA        0xFFFFFFFF     /* USART6                             */
#define TIM8_BA         0xFFFFFFFF     /* TIM8                               */
#define TIM1_BA         0xFFFFFFFF     /* TIM1                               */
#define UART8_BA        0xFFFFFFFF     /* UART8                              */
#define UART7_BA        0xFFFFFFFF     /* UART7                              */
#define CAN2_BA         0xFFFFFFFF     /* CAN2                               */
#define CAN2_BA         0xFFFFFFFF     /* CAN2                               */
#define I2C3_BA         0xFFFFFFFF     /* I2C3                               */
#define I2S3EXT_BA      0xFFFFFFFF     /* I2S3 ext                           */
#define I2S2EXT_BA      0xFFFFFFFF     /* I2S2 ext                           */
#define TIM14_BA        0xFFFFFFFF     /* TIM14                              */
#define TIM13_BA        0xFFFFFFFF     /* TIM13                              */
#define TIM12_BA        0xFFFFFFFF     /* TIM12                              */
#endif                                 /* RM0038                             */

#if RM0090                             /* RM0090 p 64-65                     */
                                       /* ---------------------------------- */
#define FSMS_BA         0xA0000000     /* FSMC                               */
#define RNG_BA          0x50060800     /* RNG                                */
#define HASH_BA         0x50060400     /* HASH                               */
#define CRYPT_BA        0x50060000     /* CRYPT                              */
#define DCMI_BA         0x50050000     /* DCMI                               */
#define USBFS_BA        0x50000000     /* USB OTG Full Speed                 */
#define USBHS_BA        0x40040000     /* USB OTG High Speed                 */
#define DMA2D_BA        0x4002B000     /* DMA2D                              */
#define ETH_BA          0x40028000     /* ETH                                */
#define DMA2_BA         0x40026400     /* DMA2                               */
#define DMA1_BA         0x40026000     /* DMA1                               */
#define BKPSRAM_BA      0x40024000     /* BKPSRAM                            */
#define FLASH_BA        0x40023C00     /* FLASH                              */
#define RCC_BA          0x40023800     /* RCC                                */
#define CRC_BA          0x40023000     /* CRC                                */
#define GPIOK_BA        0x40022800     /* GPIOK                              */
#define GPIOJ_BA        0x40022400     /* GPIOJ                              */
#define GPIOI_BA        0x40022000     /* GPIOI                              */
#define GPIOH_BA        0x40021C00     /* GPIOH                              */
#define GPIOG_BA        0x40021800     /* GPIOG                              */
#define GPIOF_BA        0x40021400     /* GPIOF                              */
#define GPIOE_BA        0x40021000     /* GPIOE                              */
#define GPIOD_BA        0x40020C00     /* GPIOD                              */
#define GPIOC_BA        0x40020800     /* GPIOC                              */
#define GPIOB_BA        0x40020400     /* GPIOB                              */
#define GPIOA_BA        0x40020000     /* GPIOA                              */
#define LCD_TFT_BA      0x40016800     /* LCD TFT                            */
#define SAI1_BA         0x40015800     /* SAI1                               */
#define SPI6_BA         0x40015400     /* SPI6                               */
#define SPI5_BA         0x40015000     /* SPI5                               */
                                       /* RM0090 page 66 ------------------- */
#define TIM11_BA        0x40014800     /* TIM11                              */
#define TIM10_BA        0x40014400     /* TIM10                              */
#define TIM9_BA         0x40014000     /* TIM9                               */
#define EXTI_BA         0x40013C00     /* EXTI                               */
#define SYSCFG_BA       0x40013800     /* SYSCFG                             */
#define SPI4_BA         0x40013400     /* SPI4                               */
#define SPI1_BA         0x40013000     /* SPI1                               */
#define SDIO_BA         0x40012C00     /* SDIO                               */
#define ADC_BA          0x40012000     /* ADC1 ADC2 ADC3                     */
#define USART6_BA       0x40011400     /* USART6                             */
#define USART1_BA       0x40011000     /* USART1                             */
#define TIM8_BA         0x40010400     /* TIM8                               */
#define TIM1_BA         0x40010000     /* TIM1                               */
#define UART8_BA        0x40007C00     /* UART8                              */
#define UART7_BA        0x40007800     /* UART7                              */
                                       /* RM0090 page 67 ------------------- */
#define DAC_BA          0x40007400     /* DAC                                */
#define PWR_BA          0x40007000     /* PWR                                */
#define CAN2_BA         0x40006800     /* CAN2                               */
#define CAN1_BA         0x40006400     /* CAN1                               */
#define I2C3_BA         0x40005C00     /* I2C3                               */
#define I2C2_BA         0x40005800     /* I2C2                               */
#define I2C1_BA         0x40005400     /* I2C1                               */
#define UART5_BA        0x40005000     /* UART5                              */
#define UART4_BA        0x40004C00     /* UART4                              */
#define USART3_BA       0x40004800     /* USART3                             */
#define USART2_BA       0x40004400     /* USART2                             */
#define I2S3EXT_BA      0x40004000     /* I2S3 ext                           */
#define SPI3_BA         0x40003C00     /* SPI3 and I2S3                      */
#define SPI2_BA         0x40003800     /* SPI2 and I2S2                      */
#define I2S2EXT_BA      0x40003400     /* I2S2 ext                           */
#define IWDG_BA         0x40003000     /* IWDG                               */
#define WWDG_BA         0x40002C00     /* WWDG                               */
#define RTC_BA          0x40002800     /* RTC                                */
#define TIM14_BA        0x40002000     /* TIM14                              */
#define TIM13_BA        0x40001C00     /* TIM13                              */
#define TIM12_BA        0x40001800     /* TIM12                              */
#define TIM7_BA         0x40001400     /* TIM7                               */
#define TIM6_BA         0x40001000     /* TIM6                               */
#define TIM5_BA         0x40000C00     /* TIM5                               */
#define TIM4_BA         0x40000800     /* TIM4                               */
#define TIM3_BA         0x40000400     /* TIM3                               */
#define TIM2_BA         0x40000000     /* TIM2                               */
                                       /* Aliases -------------------------- */
#define UART3_BA         USART3_BA     /* USART3                             */
#define UART2_BA         USART2_BA     /* USART2                             */
#define UART6_BA         USART6_BA     /* USART6                             */
#define UART1_BA         USART1_BA     /* USART1                             */
#endif                                 /* RM0090                             */


/*  3.6  Function mask per pin
    --------------------------
*/

/* Used banks: main define ..................................................*
 * The define below is based on the "Table 7. STM32F40xxx pin and ball       *
 * definitions" p47-59.                                                      */


/* Used banks ...............................................................*
 * The defines below are based on the "Table 7. STM32F40xxx pin and ball     *
 * definitions" p47-59.                                                      */


/* Pin functions ............................................................*/

#define FGPIO         (1 <<  0)        /* Bit 0  -> fct GPIO                 */


#endif                                 /* DEFS_STM32_H                       */





