/*****************************************************************************/
/*                                                                           */
/*  Hyperpanel OS                       File "include/drv_adc.h"             */
/*  Constants and definitions for ADC.                                       */
/*                                                                           */
/*  Author : AL                         Last modification : 29/12/2017       */
/*                                                                           */
/*  (c) Copyright Hyperpanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================


         1  Defines
         2  Structures and typedefs
         3  Public variables
         4  Prototypes of public procedures


*/


#ifndef DRV_ADC_H                      /* If this file is not already        */
#define DRV_ADC_H                      /* included, include it.              */


/*
    1    Defines
    ____________
*/


/* Registers ................................................................*/

#define ADC_NBREG                 6    /* Number of registers                */

/* Flags for supported bit depth per sample .................................*/

#define ADC_8BIT          (1U <<  8)   /* Device support 8 bit samples.      */
#define ADC_12BIT         (1U << 12)   /* Device support 12 bit samples.     */
#define ADC_16BIT         (1U << 16)   /* Device support 16 bit samples.     */
#define ADC_20BIT         (1U << 20)   /* Device support 20 bit samples.     */
#define ADC_24BIT         (1U << 24)   /* Device support 24 bit samples.     */
#define ADC_28BIT         (1U << 28)   /* Device support 28 bit samples.     */
#define ADC_32BIT         (1U <<  0)   /* Device support 32 bit samples.     */


/*
    2    Structures and typedefs
    ____________________________
*/


/*
   2.1  High level ADC driver definitions - Adc_drvdef
   ---------------------------------------------------
*/

typedef struct                         /* ADC driver definitions.            */
  BEGIN                                /* ---------------------------------- */
    UINT           lctx              ; /* Get start-up information on device */
    UINT           supp_depth        ; /* Sample depth supported by device.  */
    UINT           supp_dma          ; /* Sample depth supported thru DMA.   */
  END              Adc_drvdef        ; /* ---------------------------------- */



/*
    2.2 Low level ADC driver interface - Adc_desc
    ---------------------------------------------
*/

typedef struct                         /* ADC Interface                      */
  BEGIN                                /* ---------------------------------- */
    void         (*info         )()  ; /* Get start-up information on device */
    void         (*setfmt       )()  ; /* Configure format of data.          */
    void         (*itsmp        )()  ; /* Enable or disable interrupts.      */
    int          (*getsmp       )()  ; /* Get a new sample.                  */
    void         (*rcvdma       )()  ; /* Receive samples through DMA.       */
  END              Adc_desc          ; /* ---------------------------------- */


/*
   2.3  ADC device context - Adc_ctx
   ---------------------------------
*/

typedef struct                         /* ADC device context                 */
  BEGIN                                /* ---------------------------------- */
    Req_ctx        rctx              ; /* Allocation context.   req_lib.c    */
    Key_lnk        key               ; /* Intern job queues.    req_lib.c    */
    IWORD          lctx              ; /* Low-level device/context index     */
                                       /*                                    */
    Adc_drvdef    *def               ; /* Device generic definitions.        */
    void         (*setfmt       )()  ; /* Configure format of data.          */
    void         (*itsmp        )()  ; /* Enable or disable interrupts.      */
    int          (*getsmp       )()  ; /* Read a new sample.                 */
                                       /*                                    */
    UINT           reg  [ADC_NBREG]  ; /* Registers                          */
                                       /*                                    */
#ifdef NEW_ADC
    IWORD          dma               ; /* DMA in use (1) or not (0).         */
                                       /*                                    */
                                       /* Input format description --------- */
    IWORD          isz               ; /* Size in bytes of a sample.         */
                                       /*                                    */
                                       /* Output format description -------- */
    IWORD          osz               ; /* Size in bytes of a sample.         */
    IWORD          omsk              ; /* Mask to apply to sample.           */
    UCHAR          oorder       [4]  ; /* Sample byte reordering.            */
                                       /*                                    */
                                       /* Format conversion ---------------- */
    IWORD          sof7              ; /* Offset (shift) to apply to sample. */
#else
    UCHAR          sorder       [4]  ; /* Sample byte reordering.            */
    IWORD          ssz               ; /* Size in bytes of a sample.         */
    IWORD          sof7              ; /* Offset (shift) to apply to sample. */
    IWORD          smsk              ; /* Mask to apply to sample.           */
#endif
                                       /*                                    */
    UCHAR         *pbuf              ; /* Pointer to buffer to fill.         */
    IWORD          nbuf              ; /* Available place in buffer.         */
                                       /*                                    */
  END              Adc_ctx           ; /* ---------------------------------- */


  
/*
    3    Public variables
    _____________________
*/

extern UCHAR       adc_numdrv        ; /* Driver identifier for board access.*/


/*
    4    Prototypes of public procedures
    ____________________________________
*/


  void  itadcsmp            (IWORD                                           );
  void  itadcdma            (IWORD                                           );


#endif                                 /* End of DRV_ADC_H.                  */
