/*****************************************************************************/
/*                                                                           */
/*  HyperPanel VMIO                     File "stm32py/space.h"               */
/*  PYBv1.1 boards array sizes for "space_appcont.c" and "space_iocont.c"    */
/*                                                                           */
/*  Author : JYA                        Last modification : 11/11/2018       */
/*                                                                           */
/*  (c) Copyright HyperPanel Lab, All Rights Reserved                        */
/*  IDDN.FR.001.320001.*.S.P.1990.000.10000                                  */
/*                                                                           */
/*****************************************************************************/


/*  Some explanations ========================================================

         1  Purpose of this module

         2  Constants for "space_appcont.c"
            2.1  Sizes of "vmk.c" tables
            2.2  Counts and sizes of static task stacks
            2.3  Packages

         3  Constants for "space_iocont.c"
            3.1  Sizes of "vmio.c" tables
            3.2  Sizes of "req_lib.c" tables
            3.3  Sizes of the interrupt hanlers stacks


    1    Purpose of this module
    ___________________________


         This include file defines all the constants used for both 
"space_appcont.c" and "space_iocont.c", that are used with the PYBv1.1 board.


    2  Constants for "space_appcont.c"
    __________________________________

    2.1  Sizes of "vmk.c" tables
    ----------------------------
*/
#define FAI_SIZE              8        /* Size of "fai_evt[]"                */
#define TASK_SIZE             3        /* Max number of tasks                */
#define TASK_SEM_SIZE         2        /* Max number of semaphores           */
#define MAXROUTE              8        /* Max number of event's route        */
#define MAXCOND               2        /* Max number of conditions           */
#define KBD_MAX               1        /* Max number of Keyboards/RCU        */
#define NTOMAX               16        /* Max number of Time-out's           */
#define NAUTMAX              35        /* Max number of FSM's                */


/*  2.2  Counts and sizes of static task stacks
    -------------------------------------------
*/

#define NB_STACK_SZ           1        /* Count of stack sizes               */

#define STACK_SZ0             1        /* Stack size in KB                   */
#define STACK_SZ1             0        /* Stack size in KB                   */
#define STACK_SZ2             0        /* Stack size in KB                   */
#define STACK_SZ3             0        /* Stack size in KB                   */
#define STACK_SZ4             0        /* Stack size in KB                   */

#define STACK_NB0             1        /* Count of stacks of size SZ0        */
#define STACK_NB1             0        /* Count of stacks of size SZ1        */
#define STACK_NB2             0        /* Count of stacks of size SZ2        */
#define STACK_NB3             0        /* Count of stacks of size SZ3        */
#define STACK_NB4             0        /* Count of stacks of size SZ4        */


/*  2.3  Packages
    -------------------------------------------
*/

#define PKG_stm32py                    /* Use the PKG_stm32py package        */
#define PKG_vmk                        /* Task & automatons                  */


/*
    3  Constants for "space_iocont.c"
    _________________________________


    3.1  Sizes of "vmio.c" tables
    -----------------------------
*/

#define PKG_vmio                       /* Use the PKG_vmio package           */

#define MAXAUT_S             16        /* Maximum number of FSM's            */
#define MAXEVT_S             16        /* Internal waiting queue size        */
#define NTOMAX_S              8        /* Maximum number of Time-out's       */
#define MAXRTE_S              8        /* Maximum number of event's routes   */


/* 3.2  Sizes of "req_lib.c" tables
   --------------------------------
*/

#define PKG_req_lib                   /* Use the PKG_req_lib package         */

#define NBJOB                32       /* Size of "staticjob[]"               */


/* 3.3  Sizes of the interrupt hanlers stacks
   ------------------------------------------
*/

#define PKG_vmit                       /* Use the PKG_vmio package           */

#define SZ0                   0        /* Taille pile IT priorite 0 (octets) */
#define SZ1              2*1024        /* Taille pile IT priorite 1 (octets) */
#define SZ2                 512        /* Taille pile IT priorite 2 (octets) */
#define SZ3                 512        /* Taille pile IT priorite 3 (octets) */
#define SZ4                 512        /* Taille pile IT priorite 4 (octets) */
#define SZ5                 512        /* Taille pile IT priorite 5 (octets) */
#define SZ6                 512        /* Taille pile IT priorite 6 (octets) */
#define SZ7                   0        /* Taille pile IT priorite 7 (octets) */

#define OF0          (      SZ0)       /* Offset pour la base de la pile 0   */
#define OF1          (OF0 + SZ1)       /* Offset pour la base de la pile 1   */
#define OF2          (OF1 + SZ2)       /* Offset pour la base de la pile 2   */
#define OF3          (OF2 + SZ3)       /* Offset pour la base de la pile 3   */
#define OF4          (OF3 + SZ4)       /* Offset pour la base de la pile 4   */
#define OF5          (OF4 + SZ5)       /* Offset pour la base de la pile 5   */
#define OF6          (OF5 + SZ6)       /* Offset pour la base de la pile 6   */
#define OF7          (OF6 + SZ7)       /* Offset pour la base de la pile 7   */

